#ifndef NT2_INCLUDE_FUNCTIONS_MINIMUM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MINIMUM_HPP_INCLUDED

#include <nt2/reduction/include/functions/minimum.hpp>

#endif
